summaryrefslogtreecommitdiffstats
path: root/kdecore/kwinmodule.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdecore/kwinmodule.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/kwinmodule.h')
-rw-r--r--kdecore/kwinmodule.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdecore/kwinmodule.h b/kdecore/kwinmodule.h
index f680d561d..a15fd53a1 100644
--- a/kdecore/kwinmodule.h
+++ b/kdecore/kwinmodule.h
@@ -49,7 +49,7 @@ class KWinModulePrivate;
* @short Base class for KDE Window Manager modules.
* @author Matthias Ettrich (ettrich@kde.org)
*/
-class KDECORE_EXPORT KWinModule : public QObject
+class KDECORE_EXPORT KWinModule : public TQObject
{
Q_OBJECT
@@ -61,7 +61,7 @@ public:
/**
* Creates a KWinModule object and connects to the window
* manager.
* @param parent the parent for the QObject
* @param what The information you are interested in:
* INFO_DESKTOP: currentDesktop,
* numberOfDesktops,
@@ -89,7 +89,7 @@ public:
/**
* Creates a KWinModule object and connects to the window
* manager.
* @param parent the parent for the QObject
**/
KWinModule( TQObject* parent = 0 );
@@ -298,7 +298,7 @@ signals:
/**
* The window changed.
*
- * The properties parameter contains the NET properties that
+ * The properties parameter tqcontains the NET properties that
* were modified (see netwm_def.h). First element are NET::Property
* values, second element are NET::Property2 values (i.e. the format
* is the same like for the NETWinInfo class constructor).
@@ -311,7 +311,7 @@ signals:
* @deprecated
* The window changed.
*
- * The unsigned int parameter contains the NET properties that
+ * The unsigned int parameter tqcontains the NET properties that
* were modified (see netwm_def.h).
* @param id the id of the window
* @param properties the properties that were modified
@@ -61,7 +61,7 @@ public:
* Creates a KWinModule object and connects to the window
* manager.
- * @param parent the parent for the QObject
+ * @param parent the parent for the TQObject
* @param what The information you are interested in:
* INFO_DESKTOP: currentDesktop,
@@ -89,7 +89,7 @@ public:
* Creates a KWinModule object and connects to the window
* manager.
- * @param parent the parent for the QObject
+ * @param parent the parent for the TQObject
**/
KWinModule( TQObject* parent = 0 );